@@ -14,7 +14,7 @@ class DegreeWINE(EnsmallenEmbedder):
         self,
         embedding_size: int = 100,
         dtype: Optional[str] = "u8",
-        walk_length: int = 2,
+        window_size: int = 2,
         path: Optional[str] = None,
         verbose: bool = False,
         enable_cache: bool = False
@@ -27,8 +27,9 @@ class DegreeWINE(EnsmallenEmbedder):
             Dimension of the embedding.
         dtype: Optional[str] = "u8"
             Dtype to use for the embedding.
-        walk_length: int = 2
-            Length of the random walk.
+        window_size: int = 2
+            Size of the co-occurrence window.
+            Do note that for `window_size = 2` we will use the Two-Hop WINE version, which is more efficient.
             By default 2, to capture exclusively the immediate context.
         path: Optional[str] = None
             Path where to store the mmap-ed embedding.
@@ -41,12 +42,12 @@ class DegreeWINE(EnsmallenEmbedder):
         """
         self._dtype = dtype
         self._verbose = verbose
-        self._walk_length = walk_length
+        self._window_size = window_size
         self._path = path
         self._model = models.DegreeWINE(
             embedding_size=embedding_size,
             verbose=self._verbose,
-            walk_length=self._walk_length,
+            window_size=self._window_size,
             path=self._path
         )
 
@@ -61,7 +62,7 @@ class DegreeWINE(EnsmallenEmbedder):
             **super().parameters(),
             **dict(
                 dtype=self._dtype,
-                walk_length=self._walk_length,
+                window_size=self._window_size,
                 path=self._path,
             )
         )
