@@ -16,7 +16,7 @@ class ScoreWINE(EnsmallenEmbedder):
         scores: Optional[np.ndarray] = None,
         embedding_size: int = 100,
         dtype: Optional[str] = "u8",
-        walk_length: Optional[int] = None,
+        window_size: int = 2,
         path: Optional[str] = None,
         verbose: bool = False,
         enable_cache: bool = False
@@ -31,8 +31,9 @@ class ScoreWINE(EnsmallenEmbedder):
             Dimension of the embedding.
         dtype: Optional[str] = "u8"
             Dtype to use for the embedding.
-        walk_length: int = 2
-            Length of the random walk.
+        window_size: int = 2
+            Size of the co-occurrence window.
+            Do note that for `window_size = 2` we will use the Two-Hop WINE version, which is more efficient.
             By default 2, to capture exclusively the immediate context.
         path: Optional[str] = None
             Path where to store the mmap-ed embedding.
@@ -45,13 +46,13 @@ class ScoreWINE(EnsmallenEmbedder):
         """
         self._dtype = dtype
         self._verbose = verbose
-        self._walk_length = walk_length
+        self._window_size = window_size
         self._path = path
         self._scores = scores
         self._model = models.ScoreWINE(
             embedding_size=embedding_size,
             verbose=self._verbose,
-            walk_length=self._walk_length,
+            window_size=self._window_size,
             path=self._path
         )
 
@@ -66,7 +67,7 @@ class ScoreWINE(EnsmallenEmbedder):
             **super().parameters(),
             **dict(
                 dtype=self._dtype,
-                walk_length=self._walk_length,
+                window_size=self._window_size,
                 path=self._path,
             )
         )
