@@ -1412,7 +1412,7 @@ class AbstractClassifierModel(AbstractModel):
         capture_enable_cache_arg_name=False,
         use_approximated_hash=True
     )
-    def __evaluate_on_single_holdout(
+    def _evaluate_on_single_holdout(
         cls,
         models: Union[Type["AbstractClassifierModel"], List[Type["AbstractClassifierModel"]]],
         library_names: Optional[Union[str, List[str]]],
@@ -1628,9 +1628,9 @@ class AbstractClassifierModel(AbstractModel):
     @Cache(
         cache_path="{cache_dir}/{cls.task_name()}/{graph.get_name()}/{_hash}.csv.gz",
         cache_dir="experiments",
-        enable_cache_arg_name="enable_cache",
+        enable_cache_arg_name="enable_top_layer_cache",
         args_to_ignore=["verbose", "smoke_test"],
-        capture_enable_cache_arg_name=False,
+        capture_enable_cache_arg_name=True,
         use_approximated_hash=True
     )
     def evaluate(
@@ -1652,6 +1652,7 @@ class AbstractClassifierModel(AbstractModel):
         precompute_constant_stocastic_features: bool = False,
         smoke_test: bool = False,
         number_of_slurm_nodes: Optional[int] = None,
+        slurm_node_id_variable: str = "SLURM_GRAPE_ID",
         **validation_kwargs: Dict
     ) -> pd.DataFrame:
         """Execute evaluation on the provided graph.
@@ -1710,6 +1711,9 @@ class AbstractClassifierModel(AbstractModel):
         number_of_slurm_nodes: Optional[int] = None
             Number of SLURM nodes to consider as available.
             This variable is used to parallelize the holdouts accordingly.
+        slurm_node_id_variable: str = "SLURM_GRAPE_ID"
+            Name of the system variable to use as SLURM node id.
+            It must be set in the slurm bash script.
         **validation_kwargs: Dict
             kwargs to be forwarded to the model `_evaluate` method.
         """
@@ -1761,7 +1765,7 @@ class AbstractClassifierModel(AbstractModel):
                 raise ValueError(
                     "The number of SLURM nodes must be a positive integer value."
                 )
-            if number_of_holdouts <= number_of_slurm_nodes:
+            if number_of_holdouts > number_of_slurm_nodes:
                 raise ValueError(
                     (
                         "Please be advised that you are currently running an excessive "
@@ -1880,12 +1884,29 @@ class AbstractClassifierModel(AbstractModel):
         )
 
         if number_of_slurm_nodes is not None:
-            metadata["slurm_node_id"] = get_slurm_node_id()
+            if slurm_node_id_variable not in os.environ:
+                raise ValueError(
+                    (
+                        "Please do be advised that you have not provided "
+                        "the {slurm_node_id_variable} variable but you have provided specified that "
+                        "we should parallelize the holdouts across {number_of_slurm_nodes} nodes. "
+                        "Please do make available this variable in the "
+                        "slurm bash script by using the `export` flag "
+                        "in a script similar to the following:\n"
+                        "`srun --export=ALL,{slurm_node_id_variable}=$node_id` python3 your_script.py\n"
+                        "You can learn more about this in the library tutorials."
+                    ).format(
+                        slurm_node_id_variable=slurm_node_id_variable,
+                        number_of_slurm_nodes=number_of_slurm_nodes
+                    )
+                )
+            slurm_node_id = int(os.environ[slurm_node_id_variable])
+            metadata["slurm_node_id"] = slurm_node_id
             metadata["number_of_slurm_nodes"] = number_of_slurm_nodes
 
         # We start to iterate on the holdouts.
         performance = pd.concat([
-            cls.__evaluate_on_single_holdout(
+            cls._evaluate_on_single_holdout(
                 models=models,
                 library_names=library_names,
                 graph=graph,
@@ -1902,7 +1923,7 @@ class AbstractClassifierModel(AbstractModel):
                 smoke_test=smoke_test,
                 holdouts_kwargs=holdouts_kwargs,
                 subgraph_of_interest_has_compatible_nodes=subgraph_of_interest_has_compatible_nodes,
-                verbose=verbose,
+                verbose=verbose and (number_of_slurm_nodes is None or slurm_node_id==0),
                 features_names=features_names,
                 features_parameters=features_parameters,
                 metadata=metadata.copy(),
@@ -1910,7 +1931,7 @@ class AbstractClassifierModel(AbstractModel):
             )
             for holdout_number in trange(
                 number_of_holdouts,
-                disable=not verbose,
+                disable=not (verbose and (number_of_slurm_nodes is None or slurm_node_id==0)),
                 leave=False,
                 dynamic_ncols=True,
                 desc=f"Evaluating on {graph.get_name()}"
@@ -1921,7 +1942,7 @@ class AbstractClassifierModel(AbstractModel):
                     # We need to also mode the number of SLURM node IDs
                     # because the user may be parallelizing across many
                     # diffent nodes in contexts such as wide grid searches.
-                    get_slurm_node_id() % number_of_slurm_nodes
+                    slurm_node_id % number_of_slurm_nodes
                 ) == (
                     # We need to mode the holdout number as the number
                     # of holdouts may exceed the number of available SLURM
